@@ -1,6 +1,6 @@
 // cmdlineparser.cc -- Command-line parser
 //
-//  Copyright (C) 2005, 2006, 2007, 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2005, 2006, 2007, 2010, 2012  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -44,6 +44,15 @@ CmdLineParser::err (const string &phrase) const
   err (phrase.c_str ());
 }
 
+// Print a "Try prog --help for more help" message and exit
+//
+void
+CmdLineParser::try_help_err () const
+{
+  cerr << "Try `" << prog_name() << " --help' for more information" << endl;
+  exit (10);
+}
+
 
 // Option handling
 
