@@ -1,6 +1,6 @@
 // cmdlineparser.h -- Command-line parser
 //
-//  Copyright (C) 2005, 2006, 2007, 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2005, 2006, 2007, 2010, 2011, 2012  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __CMDLINEPARSER_H__
-#define __CMDLINEPARSER_H__
+#ifndef SNOGRAY_CMDLINEPARSER_H
+#define SNOGRAY_CMDLINEPARSER_H
 
 #include <string>
 #include <stdexcept>
@@ -82,6 +82,10 @@ public:
   std::string err_pfx () const;
   std::string opt_err_pfx () const;
 
+  // Print a "Try prog --help for more help" message and exit
+  //
+  void try_help_err () const __attribute__ ((noreturn));
+
   const char *get_arg ();
   int num_remaining_args () const;
 
@@ -179,6 +183,6 @@ private:
 
 }
 
-#endif /* __CMDLINEPARSER_H__ */
+#endif /* SNOGRAY_CMDLINEPARSER_H */
 
 // arch-tag: 5852e7d6-c333-492e-8c89-0f6ef8f09056
