@@ -1,6 +1,6 @@
 // color.h -- Color datatype
 //
-//  Copyright (C) 2005, 2006, 2007, 2008, 2010, 2011  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2005-2008, 2010-2012  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __COLOR_H__
-#define __COLOR_H__
+#ifndef SNOGRAY_COLOR_H
+#define SNOGRAY_COLOR_H
 
 #include "snogmath.h"
 #include "tuple-adaptor.h"
@@ -20,6 +20,11 @@
 namespace snogray {
 
 
+// Light intensity.
+//
+typedef float intens_t;
+
+
 // A color.
 //
 // Abstract color type.  This is mostly an opaque type, and as many
@@ -33,7 +38,7 @@ public:
 
   // Type of one color component.
   //
-  typedef float component_t;
+  typedef intens_t component_t;
 
   // Number of color components stored.
   //
@@ -117,7 +122,7 @@ public:
   void operator*= (double scale)
   {
     for (unsigned c = 0; c < NUM_COMPONENTS; c++)
-      _components[c] *= scale;
+      _components[c] *= component_t (scale);
   }
   void operator*= (int scale)
   {
@@ -152,7 +157,7 @@ public:
   void operator/= (int denom)      { *this *= 1 / component_t (denom); }
   void operator/= (unsigned denom) { *this *= 1 / component_t (denom); }
 
-  component_t intensity () const
+  intens_t intensity () const
   {
     component_t sum = _components[0];
     for (unsigned c = 1; c < NUM_COMPONENTS; c++)
@@ -160,7 +165,7 @@ public:
     return sum / NUM_COMPONENTS;
   }
 
-  Color clamp (float max_intens) const
+  Color clamp (intens_t max_intens) const
   {
     Color rval;
     for (unsigned c = 0; c < NUM_COMPONENTS; c++)
@@ -316,14 +321,14 @@ inline Color operator* (const Color &col, double scale)
 {
   Color rval;
   for (unsigned c = 0; c < Color::NUM_COMPONENTS; c++)
-    rval[c] = col[c] * scale;
+    rval[c] = col[c] * Color::component_t (scale);
   return rval;
 }
 inline Color operator* (double scale, const Color &col)
 {
   Color rval;
   for (unsigned c = 0; c < Color::NUM_COMPONENTS; c++)
-    rval[c] = col[c] * scale;
+    rval[c] = col[c] * Color::component_t (scale);
   return rval;
 }
 inline Color operator* (const Color &col, int scale)
@@ -452,7 +457,7 @@ private:
 
 }
 
-#endif /* __COLOR_H__ */
+#endif /* SNOGRAY_COLOR_H */
 
 
 // arch-tag: 389b3ebb-55a4-4d70-afbe-91bdb72d28ed
