@@ -1,6 +1,6 @@
 // global-render-state.h -- global information used during rendering
 //
-//  Copyright (C) 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,10 +10,9 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __GLOBAL_RENDER_STATE_H__
-#define __GLOBAL_RENDER_STATE_H__
+#ifndef SNOGRAY_GLOBAL_RENDER_STATE_H
+#define SNOGRAY_GLOBAL_RENDER_STATE_H
 
-#include "space-builder.h"
 #include "sample-gen.h"
 #include "surface-integ.h"
 #include "volume-integ.h"
@@ -50,17 +49,12 @@ public:
 
   // A table of named parameters that can affect rendering.
   //
-  const ValTable &params;
+  const ValTable params;
 
   // Sample generator.
   //
   UniquePtr<SampleGen> sample_gen;
 
-  // Factory used to create SpaceBuilder objects when creating a new
-  // geometry accelerator.
-  //
-  UniquePtr<SpaceBuilderFactory> space_builder_factory;
-
   // Global state for volume integrators.
   // 
   // This should be one of the last fields, so it will be initialized
@@ -89,8 +83,6 @@ private:
   // object based on what's in PARAMS.
   //
   static SampleGen *make_sample_gen (const ValTable &params);
-  static SpaceBuilderFactory *make_space_builder_factory (
-				const ValTable &params);
   //
   // The following helper methods are called after initialization is
   // complete, so aren't static (and can't be, as they refer to this).
@@ -104,4 +96,4 @@ private:
 
 }
 
-#endif // __GLOBAL_RENDER_STATE_H__
+#endif // SNOGRAY_GLOBAL_RENDER_STATE_H
