@@ -10,18 +10,23 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
+#include "primitive.h"
+
 #include "glow.h"
 
+
 using namespace snogray;
 
 
 Glow::Glow (const TexVal<Color> &col)
-  : color (col)
+  : Material (EMITS_LIGHT),
+    color (col)
 { }
 
 Glow::Glow (const TexVal<Color> &col,
 	    const Ref<const Material> &_underlying_material)
-  : color (col), underlying_material (_underlying_material)
+  : Material (EMITS_LIGHT),
+    color (col), underlying_material (_underlying_material)
 {
   bump_map = _underlying_material->bump_map;
 }
@@ -50,5 +55,15 @@ Glow::medium () const
   return underlying_material ? underlying_material->medium () : 0;
 } 
 
+// If this is a light-emitting material, call PRIMITIVE's
+// Primitive::add_light method with an appropriate intensity to add a
+// light to LIGHTS (for non-light-emitting materials, do nothing).
+//
+void
+Glow::add_light (const Primitive &primitive, std::vector<Light *> &lights) const
+{
+  primitive.add_light (color, lights);
+}
+
 
 // arch-tag: af19d9b6-7b4a-49ec-aee4-529be6aba253
