@@ -1,6 +1,6 @@
 // image-byte-vec.cc -- Common code for image formats based on vectors of bytes
 //
-//  Copyright (C) 2005, 2006, 2007, 2008, 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2005-2008, 2010-2012  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -21,9 +21,9 @@
 using namespace snogray;
 
 
-// ByteVecIo constructor
+// ByteVecImageIo constructor
 
-ByteVecIo::ByteVecIo (const ValTable &params)
+ByteVecImageIo::ByteVecImageIo (const ValTable &params)
   //
   // pixel-format related fields are set in the body below.
   //
@@ -40,60 +40,86 @@ ByteVecIo::ByteVecIo (const ValTable &params)
   bool alpha_channel = params.get_bool ("alpha-channel,alpha", false);
 
   std::string orig_pxfmt_name = pxfmt_name;
-  size_t pxfmt_name_len = pxfmt_name.length ();
+
+  pxfmt_name = downcase (pxfmt_name);
 
   // Stuff we figure out.
   //
   PixelFormat pxfmt;		// the pixel format
-  unsigned comp_len = 1;	// length of each pixel format in bytes
 
-  if (pxfmt_name_len > 2 && pxfmt_name.substr (pxfmt_name_len - 2) == "16")
+  // First handle basic type of pixel: rgb or greyscale
+  //
+  if (pxfmt_name.substr (0, 3) == "rgb")
     {
-      comp_len = 2;
-      pxfmt_name.erase (pxfmt_name_len - 2);
-      pxfmt_name_len -= 2;
+      pxfmt = PIXEL_FORMAT_RGB;
+      pxfmt_name.erase (0, 3);
+    }
+  else if (pxfmt_name.substr (0, 4) == "grey"
+	   || pxfmt_name.substr (0, 4) == "gray")
+    {
+      pxfmt = PIXEL_FORMAT_GREY;
+      pxfmt_name.erase (0, 4);
+    }
+  else if (pxfmt_name.substr (0, 1) == "g")
+    {
+      pxfmt = PIXEL_FORMAT_GREY;
+      pxfmt_name.erase (0, 1);
+    }
+  else
+    {
+    bad_pixel_format:
+      throw std::runtime_error ("unknown pixel format: " + orig_pxfmt_name);
     }
 
-  if (pxfmt_name_len > 1 && tolower (pxfmt_name[pxfmt_name_len - 1]) == 'a')
+  // Now handle an optional alpha channel
+  //
+  if (pxfmt_name.substr (0, 1) == "a")
     {
       alpha_channel = true;
-      pxfmt_name.erase (pxfmt_name_len - 1);
-      pxfmt_name_len -= 1;
+      pxfmt_name.erase (0, 1);
+    }
+  else if (pxfmt_name.substr (0, 5) == "alpha")
+    {
+      alpha_channel = true;
+      pxfmt_name.erase (0, 5);
     }
 
-  if (pxfmt_name == "g")
-    pxfmt = PIXEL_FORMAT_GREY;
-  else if (pxfmt_name == "rgb")
-    pxfmt = PIXEL_FORMAT_RGB;
-  else
-    throw std::runtime_error ("unknown pixel format: " + orig_pxfmt_name);
+  // Now an optional component-length (in bits), which applies to all
+  // components and the alpha channel (and is rounded up to a multiple
+  // of eight get the number of bytes per component used in
+  // byte-vectors).
+  //
+  unsigned comp_bits = 8, comp_bytes = 1;
+
+  if (! pxfmt_name.empty ())
+    {
+      char *end_ptr;
+      comp_bits = strtoul (pxfmt_name.c_str (), &end_ptr, 10);
+      if (*end_ptr != '\0' || comp_bits < 1 || comp_bits > 16)
+	goto bad_pixel_format;
+
+      comp_bytes = (comp_bits + 7) / 8;
+    }
 
   if (alpha_channel)
     pxfmt = pixel_format_add_alpha_channel (pxfmt);
 
   // Finally, set the pixel format.
   //
-  set_pixel_format (pxfmt, comp_len);
-}
-
-
-ByteVecIo::ByteVecIo (PixelFormat pxfmt, unsigned _bytes_per_component,
-		      float _target_gamma)
-  //
-  // pixel-format related fields are set in the body below.
-  //
-  : target_gamma (_target_gamma)
-{
-  set_pixel_format (pxfmt, _bytes_per_component);
+  set_pixel_format (pxfmt, comp_bytes, comp_bits);
 }
 
 
-// ByteVecIo::set_pixel_format
+// ByteVecImageIo::set_pixel_format
 
-// Set the pixel format.
+// Set the pixel format.  BYTES_PER_COMPONENT is optional and
+// defaults to 1; BITS_PER_COMPONENT should be less than or equal to
+// 8*BYTES_PER_COMPONENT, and defaults to 8*BYTES_PER_COMPONENT.
 //
 void
-ByteVecIo::set_pixel_format (PixelFormat pxfmt, unsigned _bytes_per_component)
+ByteVecImageIo::set_pixel_format (PixelFormat pxfmt,
+				  unsigned _bytes_per_component,
+				  unsigned _bits_per_component)
 {
   pixel_format = pxfmt;
 
@@ -114,9 +140,19 @@ ByteVecIo::set_pixel_format (PixelFormat pxfmt, unsigned _bytes_per_component)
       pixel_format_name += "a";
     }
 
+  // Default _BITS_PER_COMPONENT to 8 * _BYTES_PER_COMPONENT.
+  //
+  if (_bits_per_component == 0)
+    _bits_per_component = 8 * _bytes_per_component;
+
   bytes_per_component = _bytes_per_component;
-  if (bytes_per_component == 2)
-    pixel_format_name += "16";
+  bits_per_component = _bits_per_component;
+
+  // 8 bits per component is the default, so include anything else in
+  // the name.
+  //
+  if (bits_per_component != 8)
+    pixel_format_name += stringify (bits_per_component);
 }
 
 
@@ -125,11 +161,12 @@ ByteVecIo::set_pixel_format (PixelFormat pxfmt, unsigned _bytes_per_component)
 ByteVecImageSink::ByteVecImageSink (const std::string &filename,
 				    unsigned width, unsigned height,
 				    const ValTable &params)
-  : ImageSink (filename, width, height, params), ByteVecIo (params),
-    component_scale (1 << (bytes_per_component * 8)),
-    max_component ((1 << (bytes_per_component * 8)) - 1),
+  : ImageSink (filename, width, height, params), ByteVecImageIo (params),
+    component_scale (component_t ((1 << bits_per_component) - 1)),
+    max_component ((1 << bits_per_component) - 1),
     gamma_correction (1 / target_gamma),
-    output_row (width * num_channels * bytes_per_component)
+    output_row (width * num_channels * bytes_per_component),
+    dither (params.get_bool ("dither", true))
 {
 }
 
@@ -181,10 +218,44 @@ ByteVecImageSink::write_row (const ImageRow &row)
   write_row (output_row);
 }
 
-float
-ByteVecImageSink::max_intens () const
+  // Floating-point to integer and range conversion for color
+  // components.
+  //
+unsigned
+ByteVecImageSink::color_component_to_int (component_t com)
 {
-  return 1;
+  com = max (com, 0.f);
+
+  // Gamma-correct.
+  //
+  com = pow (com, gamma_correction);
+
+  // Scale to the final range.
+  //
+  com *= component_scale;
+
+  // Add dither, which should help avoid banding of very gradual
+  // gradients when the image source has greater precision than
+  // the image output format.
+  //
+  // If the source has the same or less precision, this should
+  // basically have no effect, but to avoid problems due to
+  // accumulated error, we slightly reduce the magnitude of the noise
+  // (it's nominally in the range of 0-1) to ensure this.
+  //
+  // If we're not dithering, then bias the result so that we can
+  // exactly reproduce an input from a source with the same precision,
+  // even given some accumulated error.
+  //
+  com += dither ? (dither_noise () * 0.999f) : 0.5f;
+
+  // Clamp to the final range.
+  //
+  com = min (com, max_component);
+
+  // ... and finally, convert to an integer.
+  //
+  return unsigned (com);
 }
 
 
@@ -192,28 +263,22 @@ ByteVecImageSink::max_intens () const
 
 ByteVecImageSource::ByteVecImageSource (const std::string &filename,
 					const ValTable &params)
-  : ImageSource (filename, params), ByteVecIo (params),
-    component_scale (
-      1 / Color::component_t ((1 << (bytes_per_component * 8)) - 1)),
+  : ImageSource (filename, params), ByteVecImageIo (params),
+    component_scale (1 / component_t ((1 << bits_per_component) - 1)),
     input_row (0)
 { }
 
 void
 ByteVecImageSource::set_specs (unsigned _width, unsigned _height,
 			       PixelFormat pxfmt, unsigned _bytes_per_component,
-			       unsigned bits_per_component)
+			       unsigned _bits_per_component)
 {
   width = _width;
   height = _height;
 
-  set_pixel_format (pxfmt, _bytes_per_component);
+  set_pixel_format (pxfmt, _bytes_per_component, _bits_per_component);
 
-  // BITS_PER_COMPONENT== 0 means "use default" (8 * BYTES_PER_COMPONENT).
-  //
-  if (bits_per_component == 0)
-    bits_per_component = 8 * bytes_per_component;
-
-  component_scale = 1 / Color::component_t ((1 << bits_per_component) - 1);
+  component_scale = 1 / component_t ((1 << bits_per_component) - 1);
 
   if (width)
     input_row.resize (width * num_channels * bytes_per_component);
@@ -232,7 +297,7 @@ ByteVecImageSource::read_row (ImageRow &row)
 
   for (unsigned x = 0; x < width; x++)
     {
-      Color::component_t r, g, b, a;
+      component_t r, g, b, a;
 
       r = get_color_component (p);
 
