@@ -1,6 +1,6 @@
 // load-lua.h -- Load lua scene file
 //
-//  Copyright (C) 2007, 2008, 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2007-2008, 2010-2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __LOAD_LUA_H__
-#define __LOAD_LUA_H__
+#ifndef SNOGRAY_LOAD_LUA_H
+#define SNOGRAY_LOAD_LUA_H
 
 #include <string>
 
@@ -30,25 +30,18 @@ class ValTable;
 // exception is thrown.  Loads all parts of the scene, including lights and
 // the first camera position.
 //
-extern bool load_lua_file (const std::string &filename, const std::string &fmt,
+extern bool load_lua_file (const std::string &filename,
 			   Scene &scene, Camera &camera, ValTable &params);
 
-// If FILENAME is a format that has a Lua mesh loader, load the file named
-// FILENAME into MESH using Lua, and return true; if FILENAME is
-// unrecogized, return false.  If an error occurs during loading, an
-// exception is thrown.
-//
-extern bool load_lua_file (const std::string &filename, const std::string &fmt,
-			   Mesh &mesh);
-
 
 // Cleanup and free all global Lua state.
 //
 extern void cleanup_load_lua_state ();
 
+
 }
 
+#endif // SNOGRAY_LOAD_LUA_H
 
-#endif /* __LOAD_LUA_H__ */
 
 // arch-tag: 3952dbec-b73a-40ac-92a9-38382f1e720e
