@@ -1,6 +1,6 @@
 // mutex.h -- mutex wrapper
 //
-//  Copyright (C) 2009, 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2009, 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -18,8 +18,8 @@
 //
 
 
-#ifndef __MUTEX_H__
-#define __MUTEX_H__
+#ifndef SNOGRAY_MUTEX_H
+#define SNOGRAY_MUTEX_H
 
 #include "config.h"
 
@@ -144,4 +144,4 @@ public:
 }
 
 
-#endif // __MUTEX_H__
+#endif // SNOGRAY_MUTEX_H
