@@ -1,6 +1,6 @@
 // photon-eval.h -- Photon-map evaluation (lighting, etc)
 //
-//  Copyright (C) 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __PHOTON_EVAL_H__
-#define __PHOTON_EVAL_H__
+#ifndef SNOGRAY_PHOTON_EVAL_H
+#define SNOGRAY_PHOTON_EVAL_H
 
 #include "bsdf.h"
 #include "dir-hist.h"
@@ -95,4 +95,4 @@ public:
 
 }
 
-#endif // __PHOTON_EVAL_H__
+#endif // SNOGRAY_PHOTON_EVAL_H
