@@ -1,6 +1,6 @@
 // photon.h -- Packet of light energy
 //
-//  Copyright (C) 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __PHOTON_H__
-#define __PHOTON_H__
+#ifndef SNOGRAY_PHOTON_H
+#define SNOGRAY_PHOTON_H
 
 #include "pos.h"
 #include "color.h"
@@ -53,4 +53,4 @@ public:
 
 }
 
-#endif // __PHOTON_H__
+#endif // SNOGRAY_PHOTON_H
