@@ -1,6 +1,6 @@
 // radical-inverse.h -- Compute "radical inverse" of a number
 //
-//  Copyright (C) 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __RADICAL_INVERSE_H__
-#define __RADICAL_INVERSE_H__
+#ifndef SNOGRAY_RADICAL_INVERSE_H
+#define SNOGRAY_RADICAL_INVERSE_H
 
 
 namespace snogray {
@@ -45,4 +45,4 @@ radical_inverse (unsigned num, unsigned base)
 
 }
 
-#endif // __RADICAL_INVERSE_H__
+#endif // SNOGRAY_RADICAL_INVERSE_H
