@@ -1,6 +1,6 @@
 // random-c0x.h -- Random number classes using C++0x std::random
 //
-//  Copyright (C) 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __RANDOM_C0X_H__
-#define __RANDOM_C0X_H__
+#ifndef SNOGRAY_RANDOM_C0X_H
+#define SNOGRAY_RANDOM_C0X_H
 
 #include <random>
 
@@ -42,4 +42,4 @@ private:
 
 }
 
-#endif // __RANDOM_C0X_H__
+#endif // SNOGRAY_RANDOM_C0X_H
