@@ -1,6 +1,6 @@
 // snogray.cc -- Main driver for snogray ray tracer
 //
-//  Copyright (C) 2005, 2006, 2007, 2008, 2010, 2011  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2005-2008, 2010-2012  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -19,16 +19,12 @@
 #include <cstring>
 #include <stdexcept>
 
-#ifdef HAVE_FENV_H
-#include <fenv.h>
-#endif
-
 #include "cmdlineparser.h"
 #include "rusage.h"
 #include "string-funs.h"
 #include "file-funs.h"
 #include "num-cores.h"
-#include "progress.h"
+#include "tty-progress.h"
 #include "globals.h"
 
 #include "scene.h"
@@ -36,9 +32,8 @@
 #include "light.h"
 #include "render-mgr.h"
 #include "recover.h"
-#include "image-output.h"
 #include "image-input.h"
-#include "image-cmdline.h"
+#include "image-sampled-output-cmdline.h"
 #include "render-cmdline.h"
 #include "scene-def.h"
 #include "camera-cmds.h"
@@ -62,41 +57,6 @@ using namespace std;
 //
 #define RECOVER_BACKUP_LIMIT 100
 
-
-// Floating-point exceptions
-
-// Try to enable those floating-point exceptions which don't interfere
-// with normal calculations.  This is to help debugging (the program
-// will die if an exception is hit).
-//
-static void
-enable_fp_exceptions ()
-{
-#if defined(USE_FP_EXCEPTIONS) && defined(HAVE_FEENABLEEXCEPT)
-
-  fexcept_t fexcepts = 0;
-
-  //
-  // We don't enable exceptions for underflow or overflow, because these can
-  // occur in normal usage, especially using single-precision floating point
-  // (although even then, overflow is pretty rare), it's somewhat annoying to
-  // explicitly guard against them, and typically the best thing to do is
-  // just let them become zero or infinity.
-  //
-
-#ifdef FE_DIVBYZERO
-  fexcepts |= FE_DIVBYZERO;
-#endif
-#ifdef FE_INVALID
-  fexcepts |= FE_INVALID;
-#endif
-
-  if (fexcepts)
-    feenableexcept (fexcepts);
-
-#endif // USE_FP_EXCEPTIONS && HAVE_FEENABLEEXCEPT
-}
-
 
 // LimitSpec datatype
 
@@ -148,7 +108,7 @@ LimitSpec::parse (const char *&str)
 	  frac_val /= 100;
 	}
 
-      if (frac_val < 0 || frac_val > 1.0)
+      if (frac_val < 0 || frac_val > 1)
 	return false;
     }
   else
@@ -273,7 +233,7 @@ s SCENE_DEF_OPTIONS_HELP
 n
 s " Output image options:"
 n
-s IMAGE_OUTPUT_OPTIONS_HELP
+s IMAGE_SAMPLED_OUTPUT_OPTIONS_HELP
 n
 s "  -L, --limit=X,Y+W,H        Limit output to area X,Y - X+W,Y+H"
 s "  -L, --limit=X1,Y1-X2,Y2    Limit output to area X1,Y1 - X2,Y2"
@@ -319,7 +279,7 @@ int main (int argc, char *const *argv)
 #endif
 
     RENDER_LONG_OPTIONS,
-    IMAGE_OUTPUT_LONG_OPTIONS,
+    IMAGE_SAMPLED_OUTPUT_LONG_OPTIONS,
     CMDLINEPARSER_GENERAL_LONG_OPTIONS,
 
     { 0, 0, 0, 0 }
@@ -332,8 +292,7 @@ int main (int argc, char *const *argv)
 #endif
     SCENE_DEF_SHORT_OPTIONS
     RENDER_SHORT_OPTIONS
-    IMAGE_OUTPUT_SHORT_OPTIONS
-    IMAGE_INPUT_SHORT_OPTIONS
+    IMAGE_SAMPLED_OUTPUT_SHORT_OPTIONS
     CMDLINEPARSER_GENERAL_SHORT_OPTIONS;
   //
   CmdLineParser clp (argc, argv, short_options, long_options);
@@ -344,7 +303,7 @@ int main (int argc, char *const *argv)
   LimitSpec limit_max_x_spec ("max-x", 1.0), limit_max_y_spec ("max-y", 1.0);
   unsigned num_threads = 0;	// autodetect
   bool recover = false;
-  Progress::Verbosity verbosity = Progress::CHATTY;
+  TtyProgress::Verbosity verbosity = TtyProgress::CHATTY;
   bool progress_set = false;
   ValTable output_params, render_params;
   SceneDef scene_def;
@@ -381,14 +340,14 @@ int main (int argc, char *const *argv)
       case 'q':
 	quiet = true;
 	if (! progress_set)
-	  verbosity = Progress::QUIET;
+	  verbosity = TtyProgress::QUIET;
 	break;
       case 'p':
-	verbosity = Progress::CHATTY;
+	verbosity = TtyProgress::CHATTY;
 	progress_set = true;
 	break;
       case 'P':
-	verbosity = Progress::QUIET;
+	verbosity = TtyProgress::QUIET;
 	progress_set = true;
 	break;
 
@@ -402,7 +361,7 @@ int main (int argc, char *const *argv)
 
 	// Image options
 	//
-	IMAGE_OUTPUT_OPTION_CASES (clp, output_params);
+	IMAGE_SAMPLED_OUTPUT_OPTION_CASES (clp, output_params);
 
 	// Generic options
 	//
@@ -484,15 +443,6 @@ int main (int argc, char *const *argv)
   Rusage scene_end_ru;		// stop timing scene definition
 
 
-  // Enable floating-point exceptions if possible, which can help debugging.
-  // Note that we do this _after_ reading the scene which helps avoid
-  // problems with libraries that are not expecting floating-point exceptions
-  // to be enabled (code must be compiled with -ftrapping-math to inform the
-  // compiler that floating-point operations may trap).
-  //
-  enable_fp_exceptions ();
-
-
   // Get the final image size.
   //
   get_image_size (output_params, camera.aspect_ratio (), DEFAULT_IMAGE_SIZE,
@@ -574,7 +524,8 @@ int main (int argc, char *const *argv)
   // with IMAGE_SINK_PARAMS or a problem creating the output image, so
   // we create the image before printing any normal output.
   //
-  ImageOutput output (file_name, limit_width, limit_height, output_params);
+  ImageSampledOutput output (file_name, limit_width, limit_height,
+			     output_params);
 
   if (output_params.get_bool ("alpha-channel,alpha")
       && !output.has_alpha_channel())
@@ -631,7 +582,7 @@ int main (int argc, char *const *argv)
   // many as there are CPU cores.
   //
   if (num_threads == 0)
-    num_threads = num_cores (1);
+    num_threads = num_cores ();
 
   if (num_threads != 1)
     std::cout << "* using " << num_threads << " threads" << std::endl;
@@ -655,17 +606,14 @@ int main (int argc, char *const *argv)
   // The pattern of pixels we will render; we add a small margin around
   // the output image to keep the edges clean.
   //
-  unsigned margin = output.filter_radius ();
-  RenderPattern pattern (limit_x - margin, limit_y - margin,
-			 limit_width + margin*2, limit_height + margin*2);
+  unsigned x_margin = output.filter_x_radius ();
+  unsigned y_margin = output.filter_y_radius ();
+  RenderPattern pattern (limit_x - x_margin, limit_y - y_margin,
+			 limit_width + x_margin*2, limit_height + y_margin*2);
 
   // Start progress indicator
   //
-  Progress prog (std::cout, "rendering...",
-		 pattern.position (pattern.begin ()),
-		 (pattern.position (pattern.end ())
-		  - pattern.position (pattern.begin ())),
-		 verbosity);
+  TtyProgress prog (std::cout, "rendering...", verbosity);
 
   // Do the actual rendering.
   //
