@@ -1,6 +1,6 @@
 -- snogray.lua -- Lua scene interface for snogray
 --
---  Copyright (C) 2007, 2008, 2009, 2010  Miles Bader <miles@gnu.org>
+--  Copyright (C) 2007-2012  Miles Bader <miles@gnu.org>
 --
 -- This source code is free software; you can redistribute it and/or
 -- modify it under the terms of the GNU General Public License as
@@ -13,13 +13,24 @@
 
 module ("snogray", package.seeall)
 
+
 local raw = require "snograw"
 
--- Swig-generated Lua modules don't return the module table from require
--- (as is recommended), but instead store it into a global variable
--- "snograw".
+-- Until recently, Swig-generated Lua modules didn't return the module
+-- table from require (as is recommended), but instead stored it into
+-- the global variable "snograw", and returned the module name
+-- instead.  For compatibility, handle both behaviors, by first
+-- calling require, and if it doesn't return a table, looking in the
+-- global variable.
 --
-raw = snograw
+if type (raw) ~= 'table' then
+   raw = snograw
+end
+
+
+-- A metatable for inheriting from the snogray environment
+--
+local inherit_snogray_metatable = { __index = _M }
 
 
 ----------------------------------------------------------------
@@ -587,7 +598,7 @@ function glass (params)
       _absorb = params.absorb or params.absorption or params[2] or _absorb
    elseif type (params) == "table" and (params.n or params.k) then
       _ior = params
-   else
+   elseif params then
       _absorb = params
    end
 
@@ -615,7 +626,7 @@ function thin_glass (params)
    then
       _ior = params.ior or params[1] or _ior
       _color = params.color or params.col or params[2] or _color
-   else
+   elseif params then
       _color = params
    end
 
@@ -785,27 +796,6 @@ function gc_ref (from, to)
 end
 
 
-----------------------------------------------------------------
---
--- scene object
---
--- We don't use the raw scene object directly because we need to
--- gc-protect objects handed to the scene.
-
-local function init_scene (raw_scene)
-   scene = raw_scene		-- this is exported
-
-   if scene_obj_gc_protect and not has_index_wrappers (scene) then
-      local wrap = index_wrappers (scene)
-
-      function wrap:add (thing)
-	 gc_ref (self, thing)
-	 return nowrap_meth_call (self, "add", thing)
-      end
-   end
-end
-
-
 ----------------------------------------------------------------
 --
 -- meshes
@@ -869,10 +859,30 @@ function triangle (mat, v0, e1, e2)
    return tripar (mat, v0, e1, e2, false)
 end
 
-function rectangle (mat, v0, e1, e2)
+function parallelogram (mat, v0, e1, e2)
    return tripar (mat, v0, e1, e2, true)
 end
 
+-- Alias for common usage
+--
+rectangle = parallelogram
+
+function parallelepiped (mat, corner, up, right, fwd)
+   return surface_group {
+      parallelogram (mat, corner, right, up);
+      parallelogram (mat, corner, up, fwd);
+      parallelogram (mat, corner, fwd, right);
+
+      parallelogram (mat, corner + up, right, fwd);
+      parallelogram (mat, corner + right, fwd, up);
+      parallelogram (mat, corner + fwd, up, right);
+   }
+end
+
+-- Alias for common usage
+--
+cube = parallelepiped
+
 -- Return an elliptical surface.
 --
 -- args: MAT, XFORM
@@ -933,10 +943,14 @@ function solid_cylinder (mat, arg1, ...)
    end
 end
 
--- Wrap the subspace constructor to record the GC link between a
--- subspace and the surface in it.
+-- space-builder-factory used for building model spaces
 --
-function subspace (surf)
+local model_space_builder_factory = nil
+
+-- Wrap the model constructor to record the GC link between a
+-- model and the surface in it.
+--
+function model (surf)
 
    -- If SURF is actually a table, make a surface-group to hold its
    -- members, and wrap that instead.
@@ -949,25 +963,29 @@ function subspace (surf)
       end
    end
 
-   local ss = raw.subspace (surf)
-
-   if scene_obj_gc_protect then
-      -- Record the GC link between SS and SURF.
-      --
-      gc_ref (ss, surf)
+   if not model_space_builder_factory then
+      model_space_builder_factory = raw.OctreeBuilderFactory ()
    end
 
-   return ss
+   local mod = raw.model (surf, model_space_builder_factory)
+
+   if scene_obj_gc_protect then
+      -- Record the GC link between MOD and SURF.
+      --
+      gc_ref (mod, surf)
+   end
+
+   return mod
 end
 
 -- If we need to protect against scene-object gcing, wrap the instance
 -- constructor to record the GC link between an instance and its
--- subspace.
+-- model.
 --
 if scene_obj_gc_protect then
-   function instance (subspace, xform)
-      local inst = raw.Instance (subspace, xform)
-      gc_ref (inst, subspace)
+   function instance (model, xform)
+      local inst = raw.Instance (model, xform)
+      gc_ref (inst, model)
       return inst
    end
 else
@@ -1600,6 +1618,7 @@ function eval_include (loaded, fenv, loaded_filename, err_msg)
    end
 end
 
+
 -- Load FILENAME evaluated the current environment.  FILENAME is
 -- searched for using the path in the "include_path" variable; while it
 -- is being evaluating, the directory FILENAME was actually loaded from
@@ -1614,41 +1633,14 @@ function include (filename)
 end
 
 
--- Map of filenames to the environment in which they were loaded.
---
-local use_envs = {}
-
--- A metatable for inheriting from the snogray environment
---
-local inherit_snogray_metatable = { __index = snogray }
-
--- A table containing entries for symbol names we _don't_ want inherited
--- because of a call to use().
---
-local dont_inherit_syms = {}
-dont_inherit_syms["_used_files"] = true
-dont_inherit_syms["_used_symbols"] = true
-
--- Load FILENAME in a dedicated environment, and arrange for its
--- functions and constants to be inherited by the caller's environment.
--- FILENAME is only loaded if it hasn't already been loaded (if it has,
--- then the previously loaded file is re-used).
---
--- "Inheritance" is done by copying, so that it only works properly for
--- functions and constants.
---
--- The variable "_used_files" in the caller's environment is used to
--- record which use() environments have previously been added to its
--- inheritance set.  It maps loaded filenames to the environment in
--- which they were loaded.  The variable "_used_symbols" in the caller's
--- environment is where symbols to be inherited are copied; the caller's
--- environment then inherits from this.
+-- Load FILENAME into the current environment.  This is like
+-- "include", but multiple attempts to load the same file are
+-- suppressed (the variable "_used_files" in the current environment
+-- is used to record which use file have already been loaded).
 --
 function use (filename)
    local loaded, loaded_filename, err_msg = load_include (filename)
-
    local callers_env = getfenv (2)
-   local used_files = callers_env._used_files
 
    if not used_files then
       used_files = {}
@@ -1656,63 +1648,11 @@ function use (filename)
    end
 
    if not used_files[loaded_filename] then
-      local use_env = use_envs[loaded_filename]
+      used_files[loaded_filename] = true
 
-      -- If this file hasn't been loaded already, load it into a new
-      -- environment.
-      --
-      if not use_env then
-	 use_env = {}
-	 use_envs[loaded_filename] = use_env
-
-	 -- Make sure the loaded file inherits the snogray interface.
-	 --
-	 setmetatable (use_env, inherit_snogray_metatable)
-
-	 eval_include (loaded, use_env, loaded_filename, err_msg)
-      end
-
-      -- Arrange for the symbols defined in USE_ENV to be inherited
-      -- by the caller.  Because we need "multiple inheritance" (more
-      -- than one call to use()), instead of directly using Lua
-      -- inheritance, we instead copy the symbols defined by each
-      -- use'd file into a table, and then use Lua inheritance to
-      -- inherit from it.
-      --
-      -- [Note that we can't copy the symbols directly into the caller's
-      -- environment because we don't want them to be seen by anybody
-      -- that calls use() on our caller.]
-      --
-      local used_syms = callers_env._used_symbols
-      if not used_syms then
-	 used_syms = {}
-	 callers_env._used_symbols = used_syms
-
-	 -- Replace the caller's metatable with our own metatable
-	 -- that inherits from USED_SYMS; thus USED_SYMS needs to
-	 -- inherit in turn from the global snogray environment.
-	 --
-	 setmetatable (used_syms, inherit_snogray_metatable)
-	 setmetatable (callers_env, {__index = used_syms}) 
-      end
-
-      -- Copy all symbols defined by the loaded file (in USE_ENV) into
-      -- the caller's "inheritance set" (USED_SYMS), where they can be
-      -- seen by the caller.  We avoid copying any symbols listed in
-      -- dont_inherit_syms.
-      --
-      for k, v in pairs (use_env) do
-	 if not dont_inherit_syms[k] then
-	    used_syms[k] = v
-	 end
-      end
-
-      -- Remember that the caller has loaded this file.
-      --
-      used_files[loaded_filename] = use_env
+      eval_include (loaded, callers_env, loaded_filename, err_msg)
+      return loaded_filename
    end
-
-   return loaded_filename
 end
 
 
@@ -1784,38 +1724,49 @@ end
 local scene_loaders = {}
 
 
--- Load a scene from FILENAME into RSCENE and RCAMERA (the "raw" scene
--- and camera objects).
+-- Load a scene from FILENAME into SCENE and CAMERA.
 --
--- Return true for a successful load, false if FILENAME is not
--- recognized as loadable, or an error string if an error occured during
--- loading.
---
--- Note that this only handles formats loaded using Lua, not those
--- handled by the C++ core.  To load any supported format, use the
--- scene "load" method.
---
-function load_scene (filename, fmt, rscene, rcamera, rparams, ...)
-   local loader = scene_loaders[fmt]
+function load_scene (filename, scene, camera, params)
+   params = params or {}
 
-   if loader then
-      -- Set up the scene object for the loader code to use.
-      --
-      init_scene (rscene)
+   local fmt = params.format or filename_ext (filename)
 
-      -- Let users use the raw camera directly.
-      --
-      camera = rcamera
+   if fmt then
+      fmt = string.lower (fmt)
+      local loader = scene_loaders[fmt]
 
-      -- and params table
-      --
-      params = rparams
+      if loader then
 
-      -- Call the loader.
-      --
-      return loader (filename, scene, camera, params, ...)
+	 -- For old versions of SWIG, we need to gc-protect objects
+	 -- handed to the scene.
+	 --
+	 if scene_obj_gc_protect and not has_index_wrappers (scene) then
+	    local wrap = index_wrappers (scene)
+
+	    function wrap:add (thing)
+	       gc_ref (self, thing)
+	       return nowrap_meth_call (self, "add", thing)
+	    end
+	 end
+
+	 -- Call the loader.
+	 --
+	 local ok, err_msg = pcall (loader, filename, scene, camera, params)
+	 if not ok then
+	    -- Prefix ERR_MSG with "FILENAME: ", unless it already
+	    -- seems to contain such a prefix (parsing code, for
+	    -- instance often adds the filename and line-number etc).
+	    if string.sub (err_msg, 1, #filename + 1) ~= filename..":" then
+	       err_msg = filename..": "..err_msg
+	    end
+	    -- propagate the error
+	    error (err_msg, 0)
+	 end
+      else
+	 error ("unknown scene format \""..fmt.."\"", 0)
+      end
    else
-      return false
+      error ("cannot determine scene format for \""..filename.."\"", 0)
    end
 end
 
@@ -1839,12 +1790,20 @@ local mesh_loaders = {}
 -- handled by the C++ core.  To load any supported format, use the
 -- mesh "load" method.
 --
-function load_mesh (filename, fmt, ...)
-   local loader = mesh_loaders[fmt]
-   if loader then
-      return loader (filename, ...)
+function load_mesh (filename, mesh, params)
+   params = params or {}
+
+   local fmt = params.format or filename_ext (filename)
+   if fmt then
+      fmt = string.lower (fmt)
+      local loader = mesh_loaders[fmt]
+      if loader then
+	 loader (filename, mesh, params)
+      else
+	 error ("unknown mesh format \""..fmt.."\"", 0)
+      end
    else
-      return false
+      error ("cannot determine mesh format for \""..filename.."\"", 0)
    end
 end
 
@@ -1853,15 +1812,20 @@ add_autoload_stub (mesh_loaders, "obj", "load-obj.lua", "load_obj")
 add_autoload_stub (mesh_loaders, "ug", "load-ug.lua", "load_ug")
 add_autoload_stub (mesh_loaders, "stl", "load-stl.lua", "load_stl")
 
+-- formats with C loaders
+--
+mesh_loaders.ply = raw.load_ply_file
+mesh_loaders.msh = raw.load_msh_file
+mesh_loaders["3ds"] = raw.load_3ds_file
+
 
 ----------------------------------------------------------------
 --
 -- Lua scene description loader
 
--- Load Lua scene description from FILENAME into RSCENE and RCAMERA.
--- Return true if the scene was loaded successfully, or an error string.
+-- Load Lua scene description from FILENAME into SCENE and CAMERA.
 --
-function scene_loaders.lua (filename, rscene, rcamera)
+function scene_loaders.lua (filename, scene, camera, params)
 
    -- Load the user's file!  This just constructs a function from the
    -- loaded file, but doesn't actually evaluate it.
@@ -1881,6 +1845,12 @@ function scene_loaders.lua (filename, rscene, rcamera)
    setmetatable (environ, inherit_snogray_metatable)
    setfenv (contents, environ)
 
+   -- Add references to the scene, camera, and parameters.
+   --
+   environ.scene = scene
+   environ.camera = camera
+   environ.params = params
+
    -- Remember filename being loaded, so we can find other files in
    -- the same location.
    --
@@ -1889,8 +1859,6 @@ function scene_loaders.lua (filename, rscene, rcamera)
    -- Finally, evaluate the loaded file!
    --
    contents ()
-
-   return true
 end
 
 -- Other types of Lua file.
@@ -1901,5 +1869,35 @@ scene_loaders.luo = scene_loaders.lua
 add_autoload_stub (scene_loaders, "nff", "load-nff.lua", "load_nff")
 add_autoload_stub (scene_loaders, "pbrt", "load-pbrt.lua", "load_pbrt")
 
+-- formats with C loaders
+--
+scene_loaders["3ds"] = raw.load_3ds_file
+
+
+----------------------------------------------------------------
+--
+-- High-level rendering functions (mainly used by the top-level driver)
+
+scene = raw.Scene
+camera = raw.Camera
+
+global_render_state = raw.GlobalRenderState
+
+render_mgr = raw.RenderMgr
+render_pattern = raw.RenderPattern
+render_stats = raw.RenderStats
+
+octree_builder_factory = raw.OctreeBuilderFactory
+
+image_output = raw.ImageOutput
+
+-- For TTY the progress reporter, we just assume std::cout
+--
+function tty_progress (msg)
+   return raw.TtyProgress (raw.cout, msg)
+end
+
+num_cores = raw.num_cores
+
 
 -- arch-tag: e5dc4da4-c3f0-45e7-a4a1-a20cb4db6d6b
