@@ -1,6 +1,6 @@
 // space.h -- Space-division abstraction (hierarchically arranges 3D space)
 //
-//  Copyright (C) 2005, 2007, 2008, 2009, 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2005, 2007, 2008, 2009, 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __SPACE_H__
-#define __SPACE_H__
+#ifndef SNOGRAY_SPACE_H
+#define SNOGRAY_SPACE_H
 
 #include "ray.h"
 #include "surface.h"
@@ -51,11 +51,6 @@ public:
   // well as transmitting it), nor does it deal with anything except
   // surfaces.
   //
-  // [This interface is slight awkward for reasons of speed --
-  // returning and checking for a boolean value for common cases is
-  // significantly faster than, for instance, a simple "transmittance"
-  // method, which requires handling Color values for all cases.]
-  //
   virtual bool occludes (const Ray &ray, const Medium &medium,
 			 Color &total_transmittance,
 			 RenderContext &context)
@@ -137,7 +132,7 @@ struct Space::SearchState
 
 }
 
-#endif // __SPACE_H__
+#endif // SNOGRAY_SPACE_H
 
 
 // arch-tag: b992c2ec-257d-4b88-9001-83a90353e668
