@@ -1,6 +1,6 @@
 // surface-integ.h -- Light integrator interface for surfaces
 //
-//  Copyright (C) 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __SURFACE_INTEG_H__
-#define __SURFACE_INTEG_H__
+#ifndef SNOGRAY_SURFACE_INTEG_H
+#define SNOGRAY_SURFACE_INTEG_H
 
 #include "ray.h"
 #include "tint.h"
@@ -64,4 +64,4 @@ protected:
 
 }
 
-#endif // __SURFACE_INTEG_H__
+#endif // SNOGRAY_SURFACE_INTEG_H
