@@ -1,6 +1,6 @@
 // surface.cc -- Physical surface
 //
-//  Copyright (C) 2005, 2006, 2007, 2008, 2009, 2010, 2011  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2005-2012  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -14,6 +14,8 @@
 
 #include "surface.h"
 #include "space.h"
+#include "space-builder.h"
+
 
 using namespace snogray;
 
@@ -27,23 +29,6 @@ Surface::add_to_space (SpaceBuilder &space_builder) const
   space_builder.add (this);
 }
 
-// Stubs -- these should be abstract methods, but C++ doesn't allow a
-// class with abstract methods to be used in a list/vector, so we just
-// signal a runtime error if they're ever called.
-
-static void barf () __attribute__ ((noreturn));
-static void
-barf ()
-{
-  throw std::runtime_error ("tried to render abstract surface");
-}
-
-const Surface::IsecInfo *
-Surface::intersect (Ray &, RenderContext &) const { barf (); }
-bool Surface::intersects (const Ray &, RenderContext &) const { barf (); }
-bool Surface::occludes (const Ray &, const Medium &, Color &, RenderContext &) const { barf ();}
-BBox Surface::bbox () const { barf (); }
-
 
 
 // Surface::Sampler
@@ -82,7 +67,7 @@ Surface::Sampler::AngularSample::AngularSample (const AreaSample &area_sample,
       // As the normal rotates away from DIR, the samples get
       // scrunched up, so the PDF goes up.
       //
-      float pdf_cos_adj = dot (-normal, dir);
+      float pdf_cos_adj = cos_angle (-normal, dir);
 
       // If PDF_COS_ADJ is negative then the light points away from
       // ISEC, and so can have no effect.
@@ -92,7 +77,7 @@ Surface::Sampler::AngularSample::AngularSample (const AreaSample &area_sample,
 	  // Area to solid-angle conversion, dw/dA, where w is a solid
 	  // angle in the hemisphere visible from the origin of VIEW_VEC.
 	  //
-	  float dw_dA = pdf_cos_adj * inv_dist * inv_dist;
+	  float dw_dA = pdf_cos_adj * float (inv_dist * inv_dist);
 	  pdf = area_sample.pdf / dw_dA;
 	}
     }
