@@ -1,6 +1,6 @@
 // tex.h -- texture base class
 //
-//  Copyright (C) 2008, 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2008, 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -10,8 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
-#ifndef __TEX_H__
-#define __TEX_H__
+#ifndef SNOGRAY_TEX_H
+#define SNOGRAY_TEX_H
 
 #include "ref.h"
 #include "intersect.h"
@@ -86,4 +86,4 @@ public:
 
 }
 
-#endif // __TEX_H__
+#endif // SNOGRAY_TEX_H
