@@ -1,6 +1,6 @@
 // thread.h -- thread wrapper
 //
-//  Copyright (C) 2009, 2010  Miles Bader <miles@gnu.org>
+//  Copyright (C) 2009, 2010, 2011  Miles Bader <miles@gnu.org>
 //
 // This source code is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License as
@@ -18,8 +18,8 @@
 //
 
 
-#ifndef __THREAD_H__
-#define __THREAD_H__
+#ifndef SNOGRAY_THREAD_H
+#define SNOGRAY_THREAD_H
 
 #include "config.h"
 
@@ -80,4 +80,4 @@ public:
 }
 
 
-#endif // __THREAD_H__
+#endif // SNOGRAY_THREAD_H
