@@ -10,6 +10,8 @@
 // Written by Miles Bader <miles@gnu.org>
 //
 
+#include <ostream>
+
 #include "nice-io.h"
 
 #include "xform-io.h"
@@ -17,21 +19,24 @@
 std::ostream&
 snogray::operator<< (std::ostream &os, const Xform &xform)
 {
-  os << "xform<";
+  // this syntax isn't the prettiest, but is kind of compatible with
+  // emacs calc, Lua, and C
 
-  for (int j = 0; j < 4; j++)
+  os << "xform{{";
+
+  for (int row = 0; row < 4; row++)
     {
-      if (j > 0)
-	os << "; ";
-      for (int i = 0; i < 4; i++)
+      if (row > 0)
+	os << "}, {";
+      for (int col = 0; col < 4; col++)
 	{
-	  if (i > 0)
+	  if (col > 0)
 	    os << ", ";
-	  output_nicely (os, xform (i, j));
+	  output_nicely (os, xform (col, row));
 	}
     }
 
-  os << ">";
+  os << "}}";
 
   return os;
 }
